==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/MTurk/UpdateHITTypeOfHIT.pm <==

package Paws::MTurk::UpdateHITTypeOfHIT;
  use Moose;
  has HITId => (is => 'ro', isa => 'Str', required => 1);
  has HITTypeId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateHITTypeOfHIT');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MTurk::UpdateHITTypeOfHITResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::UpdateHITTypeOfHIT - Arguments for method UpdateHITTypeOfHIT on Paws::MTurk

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateHITTypeOfHIT on the 
Amazon Mechanical Turk service. Use the attributes of this class
as arguments to method UpdateHITTypeOfHIT.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateHITTypeOfHIT.

As an example:

  $service_obj->UpdateHITTypeOfHIT(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> HITId => Str

The HIT to update.



=head2 B<REQUIRED> HITTypeId => Str

The ID of the new HIT type.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateHITTypeOfHIT in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/MTurk/UpdateHITTypeOfHIT.pm <==

package Paws::MTurk::UpdateHITTypeOfHIT;
  use Moose;
  has HITId => (is => 'ro', isa => 'Str', required => 1);
  has HITTypeId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateHITTypeOfHIT');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MTurk::UpdateHITTypeOfHITResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::UpdateHITTypeOfHIT - Arguments for method UpdateHITTypeOfHIT on L<Paws::MTurk>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateHITTypeOfHIT on the
L<Amazon Mechanical Turk|Paws::MTurk> service. Use the attributes of this class
as arguments to method UpdateHITTypeOfHIT.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateHITTypeOfHIT.

=head1 SYNOPSIS

    my $mturk-requester = Paws->service('MTurk');
    my $UpdateHITTypeOfHITResponse = $mturk -requester->UpdateHITTypeOfHIT(
      HITId     => 'MyEntityId',
      HITTypeId => 'MyEntityId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/mturk/>

=head1 ATTRIBUTES


=head2 B<REQUIRED> HITId => Str

The HIT to update.



=head2 B<REQUIRED> HITTypeId => Str

The ID of the new HIT type.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateHITTypeOfHIT in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
